@@ -1,5 +1,5 @@
 import sys, getopt
-import command_executer
+import pysoul.command_executer
 
 def main(argv):
     args_processing(argv)
